@@ -85,14 +85,15 @@ c         observation layer.
 #include  "Ztrackp.h"
  
 c     
-       real*8  rho, cvh2den, dedt, thick, leng, cupsilon
-       save dedt
+       real*8  rho, cvh2den, dedt, dedtF,  thick, leng, cupsilon
+       save dedt, dedtF
        real*8  csyncTELoss
        integer jcut
-       real*8  dedx  ! output.  dedt is put
+       real*8  dedx, dedxF  ! output.  dedt, dedtF is put
 
 
-       real*8  dedxmu
+       real*8  dedxmu, dedxmuF
+
 c
 c          first consider the synchrotron loss.
 c
@@ -118,13 +119,15 @@ c
 c           dE/dX
 c
        rho = cvh2den(TrackBefMove.pos.height)
-       call cdedxInAir(TrackBefMove.p, rho, dedt)  ! dedt; GeV/(kg/m2)
+       call cdedxInAir(TrackBefMove.p, rho, dedt, dedtF )  ! dedt; GeV/(kg/m2)
        if(TrackBefMove.p.code .eq. kmuon ) then
 c           dE/dx due to muon pair, brem, nuc.i
           call cmudEdx(MuNI, MuBr, MuPr, TrackBefMove.p.fm.p(4),
-     *         dedxmu)   ! dedxmu in GeV/(g/cm2)
+     *         dedxmu, dedxmuF)   ! dedxmu in GeV/(g/cm2)
           dedxmu = dedxmu /10.  !  GeV/(kg/m2)
+          dedxmuF = dedxmuF /10.  !  GeV/(kg/m2)
           dedt = dedt + dedxmu
+          dedtF = dedtF + dedxmuf
        endif
 
        EnergyLoss =  dedt * IntInfArray(ProcessNo).thickness
@@ -162,11 +165,12 @@ c          MoveStat = Truncated
        endif 
        return
 c      **************
-       entry cqElossRate(dedx)
+       entry cqElossRate(dedx, dedxF)
 c      **************
 c         inquire the dedt; which may be used when particle cross 
 c         an obs. level and recompute the energy
        dedx = dedt
+       dedxF = dedtF
        end
 c      --------------------------------------------------------------
        subroutine cputDeflection
