@@ -57,8 +57,8 @@ c
       integer jcut
 
 
-      erg = TrackBefMove.p.fm.p(4)
-      if( erg .le. TrackBefMove.p.mass ) then
+      erg = TrackBefMove.p.fm.p(4) - TrackBefMove.p.mass 
+      if( erg .le. 0.) then
          leng = 0.
          thick = 0.
          return  !  *****
@@ -75,6 +75,7 @@ c            mul. scatt and lpm
          if(Reverse .eq. 0) then
 c               scattering effect; streight and scattered line must be
 c               not so much different ; path < ztrunc (kg/m2)
+c             1 kg/m2 = 1000g/10^4 cm2 = 0.1g/cm2
             call cmaxCasLen(TrackBefMove, ztrunc)
             if(TrackBefMove.p.code .eq. kelec .and. 
      *         TrackBefMove.p.fm.p(4) .gt. LpmBremEmin
@@ -83,6 +84,9 @@ c               not so much different ; path < ztrunc (kg/m2)
      *         max( min(TrackBefMove.pos.depth/10., ztrunc), 
      *              30.d0 )
             endif
+            if( ztrunc .gt. maxstep(TrackBefMove.where) ) then
+               ztrunc =  maxstep(TrackBefMove.where)
+            endif
 
             call cthick2len(TrackBefMove,
      *          ztrunc, leng, thick, jcut)
@@ -101,7 +105,7 @@ cc            endif
             thick = 0.
          else
             leng = rmg
-            thick = clen2thick(TrackBefMove.pos.height,
+            thick = clen2thick( TrackBefMove.pos.height,
      *         TrackBefMove.vec.coszenith, rmg)
          endif
       else
@@ -182,8 +186,10 @@ c
 
       ek = aTrack.p.fm.p(4) - aTrack.p.mass
       if(ek .gt. 1.d-3) then
+c             1MeV -->5e-3 r.l   --> 360*5e-3 kg/m2~  1.8 kg/m2
          ttrunc=min( ek*5.0d0, 1.d0)
       else
+c                1e-3 r.l  --> 365e-3 ~  0.3 kg/m2
          ttrunc = max(1.d-3, ek*2.d0)
       endif
       kgpm2= ttrunc*X0
